Remove a duplicate definition of VP set (hv_vp_set) and use the common
definition (hv_vpset) that is used in other places.

Change the order of the members in struct hv_pcibus_device so that the
declaration of retarget_msi_interrupt_params is the last member. Struct
hv_vpset, which contains a flexible array, is nested two levels deep in
struct hv_pcibus_device via retarget_msi_interrupt_params.

Add a comment that retarget_msi_interrupt_params should be the last
member of struct hv_pcibus_device.

Signed-off-by: Maya Nakamura <m.maya.nakam...@gmail.com>
Reviewed-by: Michael Kelley <mikel...@microsoft.com>
Reviewed-by: Vitaly Kuznetsov <vkuzn...@redhat.com>
Tested-by: Vitaly Kuznetsov <vkuzn...@redhat.com>
---
Changes in v5:
 - Remove the code added in v4.
 - Delete the v4 code change related comment from the commit message.
 - Add the Reviewed-by and Tested-by tags.

Changes in v4:
 - Add __aligned(8) to struct retarget_msi_interrupt.
 - Update the commit message.

Change in v3:
 - Correct the v2 change log.

Change in v2:
 - Update the commit message.

 drivers/pci/controller/pci-hyperv.c | 25 ++++++++++++-------------
 1 file changed, 12 insertions(+), 13 deletions(-)

diff --git a/drivers/pci/controller/pci-hyperv.c 
b/drivers/pci/controller/pci-hyperv.c
index 73862eef09ec..d71695db1ba0 100644
--- a/drivers/pci/controller/pci-hyperv.c
+++ b/drivers/pci/controller/pci-hyperv.c
@@ -393,12 +393,6 @@ struct hv_interrupt_entry {
 
 #define HV_VP_SET_BANK_COUNT_MAX       5 /* current implementation limit */
 
-struct hv_vp_set {
-       u64     format;                 /* 0 (HvGenericSetSparse4k) */
-       u64     valid_banks;
-       u64     masks[HV_VP_SET_BANK_COUNT_MAX];
-};
-
 /*
  * flags for hv_device_interrupt_target.flags
  */
@@ -410,7 +404,7 @@ struct hv_device_interrupt_target {
        u32     flags;
        union {
                u64              vp_mask;
-               struct hv_vp_set vp_set;
+               struct hv_vpset vp_set;
        };
 };
 
@@ -460,12 +454,16 @@ struct hv_pcibus_device {
        struct msi_controller msi_chip;
        struct irq_domain *irq_domain;
 
-       /* hypercall arg, must not cross page boundary */
-       struct retarget_msi_interrupt retarget_msi_interrupt_params;
-
        spinlock_t retarget_msi_interrupt_lock;
 
        struct workqueue_struct *wq;
+
+       /* hypercall arg, must not cross page boundary */
+       struct retarget_msi_interrupt retarget_msi_interrupt_params;
+
+       /*
+        * Don't put anything here: retarget_msi_interrupt_params must be last
+        */
 };
 
 /*
@@ -955,12 +953,13 @@ static void hv_irq_unmask(struct irq_data *data)
                 */
                params->int_target.flags |=
                        HV_DEVICE_INTERRUPT_TARGET_PROCESSOR_SET;
-               params->int_target.vp_set.valid_banks =
+               params->int_target.vp_set.valid_bank_mask =
                        (1ull << HV_VP_SET_BANK_COUNT_MAX) - 1;
 
                /*
                 * var-sized hypercall, var-size starts after vp_mask (thus
                 * vp_set.format does not count, but vp_set.valid_banks does).
                 */
                var_size = 1 + HV_VP_SET_BANK_COUNT_MAX;
 
@@ -974,7 +973,7 @@ static void hv_irq_unmask(struct irq_data *data)
                                goto exit_unlock;
                        }
 
-                       params->int_target.vp_set.masks[cpu_vmbus / 64] |=
+                       params->int_target.vp_set.bank_contents[cpu_vmbus / 64] 
|=
                                (1ULL << (cpu_vmbus & 63));
                }
@@ -955,12 +953,13 @@ static void hv_irq_unmask(struct irq_data *data)
                /*
                 * var-sized hypercall, var-size starts after vp_mask (thus
-                * vp_set.format does not count, but vp_set.valid_banks does).
+                * vp_set.format does not count, but vp_set.valid_bank_mask
+                * does).
                 */
                var_size = 1 + HV_VP_SET_BANK_COUNT_MAX;
        } else {
-- 
2.17.1

Reply via email to